Glossary — ASE documentation

### Navigation

- index
- modules |

# Glossary

API
  Application Programming Interface. Automatically generated documentation from docstrings in the source code using Epydoc. See here.
ASE
  Atomic Simulation Environment.
Class
  XXX
Constructor
  XXX
Docstring
  XXX
DFT
  Density Functional Theory.
EMT
  Effective Medium Theory.
HF
  Hartree-Fock approximation XXX ...
Instance
  XXX
LAPW
  In the linearized augmented plane wave (LAPW) method the unit cell of the crystal is divided into two different types of regions. The first one, called the muffin-tin region, consists of spheres centered around the atoms, while the second one, called the interstitial region consists of the remaining part of the unit cell. In the muffin-tin spheres the basis consists of atomic like functions to account for the rapid changes of the wave function in this area, whereas in the interstitial region the basis functions are plane waves, since the wave function changes only slowly at some distance from the atomic sites.
Namespace
  An abstract container of the current scope‘s variables.
ndarray
  NumPy‘s n-dimensional array. See Numeric arrays in Python.
NumPy
  XXX See Numeric arrays in Python.
Method
  XXX
Python
  XXX What is Python?.
Scope
  An enclosing context where values and expressions are associated.

### Navigation

- index
- modules |